function [x] = GaussianElimination(A,b)

n = length(b);
x = zeros(n,1);
M = zeros(n,n);

for k=1:n-1
    % Check to see if the pivot is zero
    if abs(A(k,k)) < 1e-15;
        error('A has diagonal entries of zero')
    end
    
    % Compute multipliers for current column
    for i=k+1:n
       M(i,k) = A(i,k)/A(k,k); 
    end
    
    % Apply transformation to remaining submatrix and RHS vector
    for j=k+1:n
        for i=k+1:n
            A(i,j) = A(i,j) - M(i,k)*A(k,j);
            
            % If we're updating the last column, update the RHS vector as
            % well.
            if j==n
               b(i) = b(i) - M(i,k)*b(k); 
            end
        end
    end
end

% A is now upper diagonal.  Use backsubstitution to solve the transformed problem.
x = BackSubstitution(A,b);

