function [x] = GaussianElimination_Pivoting(A,b)

n = length(b);
x = zeros(n,1);
M = zeros(n,n);

for k=1:n-1
    % Find largest pivot in column (in or beneath row k)
    [pivotVal, pivotRow] = max(abs(A(k:n,k)));
    pivotRow = pivotRow+k-1;
    
    % Interchange rows of matrix and RHS vector if pivot is beneath row k
    if (pivotRow ~= k)
        A([k pivotRow], :) = A([pivotRow k], :);
        b([k pivotRow]) = b([pivotRow k]);
    end
    
    % Compute multipliers for current column
    for i=k+1:n
       M(i,k) = A(i,k)/A(k,k); 
    end
    
    % Apply transformation to remaining submatrix and RHS vector
    for j=k+1:n
        for i=k+1:n
            A(i,j) = A(i,j) - M(i,k)*A(k,j);
            
            % If we're updating the last column, update the RHS vector as
            % well.
            if j==n
               b(i) = b(i) - M(i,k)*b(k); 
            end
        end
    end
end

% A is now upper diagonal.  Use backsubstitution to solve the transformed problem.
x = BackSubstitution(A,b);

