function [y,data] = bisect(a,b,func,tol)
% function y = bisect(a,b,func,tol)
% Uses the bisection method to find a root of 'func' in (a,b) to within tol
% Run with "bisect(a,b,'myfun',tol)"

% feval is used to evaluate functions using their string name
fa = feval(func,a);
fb = feval(func,b);

% Check that fa and fb have opposite signs (since we implicitly assume this)
if fa*fb >= 0
    error('The function fails to satisfy f(a)*f(b)<0 for inputs a and b')
end

% keep track of progress of algorithm
data = [ 0 a b fa fb b-a];

% now we can run the algorithm
it_count=0;
while (b-a) > tol
    it_count = it_count+1;
    % Get the midpoint and evaluate it
    xnew = (a+b)/2;
    fnew = feval(func,xnew);
        
    % determine which interval to keep
    if fa * fnew <= 0
        b  = xnew;
        fb = fnew;
    else
        a  = xnew;
        fa = fnew;
    end
    
    datanew = [ it_count a b fa fb b-a];

    data = [data;datanew];
end
% The solution needs to be a number - choose the midpoint of the final interval
y = (a+b)/2;
