function y = rk4(func,t,y1)
% function y = rk4(func,t,y1)
% compute approx to dy/dt = f(t,y) with initial condition y(t1)=y1
% t is a vector of the t points: [t1,t2,...,tn]

% initialize y to be the same size at t
y = 0 * t;

% initial condition
y(1)=y1;

% use BE to find y_i+1 
for i=1:length(y)-1
    dt = t(i+1) - t(i);
    
    K1 = feval(func,t(i),y(i));
    K2 = feval(func,t(i) + dt/2,y(i) + dt/2*K1);
    K3 = feval(func,t(i) + dt/2,y(i) + dt/2*K2);
    K4 = feval(func,t(i) + dt  ,y(i) + dt*K3);
    
    y(i+1) = y(i) + dt * ( K1/6 + K2/3 + K3/3 + K4/6 );
    
end
